import React, { Component } from 'react';
import { render } from 'react-dom';
import PropTypes from 'prop-types';
import 'bootstrap/dist/css/bootstrap.min.css';
import './style.css';
import { Pagination, PaginationItem, PaginationLink } from 'reactstrap';

class DynamicPagination extends Component {

  constructor(props) {
    super(props);
    const totalPages = Math.ceil(props.totalRecords / props.paginationSize);

    this.state = {
      totalRecords: props.totalRecords,
      totalPages,
      activePage: props.activePage,
      disabledPrev: true,
      disabledNext: false,
      startIndex: 1,
      endIndex: props.paginationSize
    };
  }

  nextClickHandler = () => {
    let { activePage, paginationData, totalPages, startIndex, endIndex, disabledNext, disabledPrev, disabledLast } = this.state;
    const { paginationSize } = this.props;
    if (activePage === totalPages) {
      return;
    }

    if (activePage === endIndex) {
      startIndex = activePage + 1;
      endIndex = activePage + paginationSize;

      if (endIndex > totalPages) {
        startIndex = totalPages - paginationSize + 1;
        endIndex = totalPages;
        activePage = activePage + 1;
        disabledNext = (activePage === totalPages) ? true : disabledNext;
        disabledLast = (activePage === totalPages) ? true : disabledLast;
      } else {
        activePage = startIndex;
      }

    } else {
      activePage = activePage + 1;
      disabledPrev = false;
      disabledNext = (activePage === totalPages) ? true : disabledNext;
      disabledLast = (activePage === totalPages) ? true : disabledLast;
    }

    this.setState({
      disabledNext,
      disabledPrev,
      activePage,
      startIndex,
      endIndex
    });
  }

  prevClickHandler = () => {

    let { activePage, paginationData, totalPages, startIndex, endIndex, disabledNext, disabledPrev, disabledLast, disabledFirst } = this.state;
    const { paginationSize } = this.props

    if (activePage === 1) {
      return;
    }

    if (activePage === startIndex) {
      startIndex = activePage - paginationSize;
      endIndex = activePage - 1;
      activePage = activePage - 1;

      if (startIndex < 0) {
        startIndex = 1;
        endIndex = paginationSize;
        activePage = activePage + 1;
      }

    } else {
      activePage = activePage - 1;
      disabledNext = false;
      disabledLast = false;
      disabledPrev = (activePage === 1) ? true : disabledPrev;
      disabledFirst = (activePage === 1) ? true : disabledFirst;
    }

    this.setState({
      disabledNext,
      disabledPrev,
      activePage,
      startIndex,
      endIndex,
      disabledFirst,
      disabledLast
    });
  }

  firstClickHandler = () => {
    const { activePage } = this.state;
    const { paginationSize } = this.props;

    if (activePage === 1) {
      return;
    }

    this.setState({
      disabledNext: false,
      disabledPrev: true,
      activePage: 1,
      startIndex: 1,
      endIndex: paginationSize,
      disabledFirst: true,
      disabledLast: false
    });
  }

  lastClickHandler = () => {
    const { activePage, totalPages } = this.state;
    const { paginationSize } = this.props;

    if (activePage === totalPages) {
      return;
    }

    this.setState({
      disabledNext: true,
      disabledPrev: false,
      activePage: totalPages,
      startIndex: totalPages - paginationSize + 1,
      endIndex: totalPages,
      disabledFirst: false,
      disabledLast: true
    });
  }

  pageClickHandler = (selectedPage) => {
    const { activePage, totalPages } = this.state;
    let disabledNext = false, disabledPrev = false, disabledFirst = false, disabledLast = false;

    if (selectedPage === activePage) {
      return;
    }

    if (selectedPage === totalPages) {
      disabledNext = true;
      disabledLast = true;
    }

    if (selectedPage === 1) {
      disabledPrev = true;
      disabledFirst = true;
    }

    this.setState({
      activePage: selectedPage,
      disabledNext,
      disabledPrev,
      disabledFirst,
      disabledLast
    });
  }

  render() {
    const { paginationData, activePage, disabledPrev, disabledNext, startIndex, endIndex } = this.state;
    const { paginationSize } = this.props;
    let renderPages = [];

    for (let i = startIndex; i <= endIndex; i++) {
      renderPages.push(
        <PaginationItem key={i} className={activePage === i ? 'active' : ''} onClick={() => this.pageClickHandler(i)}>
          <PaginationLink href="#">
            {i}
          </PaginationLink>
        </PaginationItem>
      )
    }

    return (
      <Pagination>
        <PaginationItem onClick={this.firstClickHandler} disabled={disabledPrev}>
          <PaginationLink first href="#" />
        </PaginationItem>
        <PaginationItem onClick={this.prevClickHandler} disabled={disabledPrev}>
          <PaginationLink previous href="#" />
        </PaginationItem>
        {renderPages}
        <PaginationItem onClick={this.nextClickHandler} disabled={disabledNext}>
          <PaginationLink next href="#" />
        </PaginationItem>
        <PaginationItem onClick={this.lastClickHandler} disabled={disabledNext}>
          <PaginationLink last href="#" />
        </PaginationItem>
      </Pagination>
    );
  }
}

DynamicPagination.propTypes = {
    totalRecords: PropTypes.number.isRequired,
    paginationSize:PropTypes.number.isRequired,
    activePage: PropTypes.number.isRequired,
    //onSelect: PropTypes.func.isRequired,
    //maxPaginationNumbers: PropTypes.number,
    //activePage: PropTypes.number
}

DynamicPagination.defaultProps = {
    paginationSize: 5,
    activePage: 1
}

export default DynamicPagination;